@@ -12,9 +12,7 @@
 #include "SharedSSLState.h"
 #include "cert.h"
 #include "certdb.h"
-#ifdef MOZ_SECURITY_SQLSTORE
 #include "mozStorageCID.h"
-#endif
 #include "mozilla/ArrayUtils.h"
 #include "mozilla/Casting.h"
 #include "mozilla/Preferences.h"
@@ -1702,17 +1700,11 @@ GetNSSProfilePath(nsAutoCString& aProfilePath)
            ("Could not get nsILocalFileWin for profile directory.\n"));
     return NS_ERROR_FAILURE;
   }
-#ifdef MOZ_SECURITY_SQLSTORE
   // SQLite always takes UTF-8 file paths regardless of the current system
   // code page.
   nsAutoString u16ProfilePath;
   rv = profileFileWin->GetCanonicalPath(u16ProfilePath);
   CopyUTF16toUTF8(u16ProfilePath, aProfilePath);
-#else
-  // Native path will drop Unicode characters that cannot be mapped to system's
-  // codepage, using short (canonical) path as workaround.
-  rv = profileFileWin->GetNativeCanonicalPath(aProfilePath);
-#endif
 #else
   // On non-Windows, just get the native profile path.
   rv = profileFile->GetNativePath(aProfilePath);
@@ -1980,13 +1972,11 @@ nsNSSComponent::Init()
     return NS_ERROR_NOT_SAME_THREAD;
   }
 
-#ifdef MOZ_SECURITY_SQLSTORE
   // To avoid an sqlite3_config race in NSS init, we require the storage service to get initialized first.
   nsCOMPtr<nsISupports> storageService = do_GetService(MOZ_STORAGE_SERVICE_CONTRACTID);
   if (!storageService) {
     return NS_ERROR_NOT_AVAILABLE;
   }
-#endif
 
   nsresult rv = NS_OK;
 
